@@ -15,8 +15,7 @@ class FoxR1S1Device(FoxBaseDevice):
 
     def __init__(self, device_data: DeviceData):
         """Initialize object by given device data."""
-        super().__init__(device_data.name, device_data.host, device_data.api_key,
-                        device_data.mac_addr, device_data.type)
+        super().__init__(device_data)
         self.__device_api_client = self.DeviceRestApiImplementer(self._rest_api_client)
         self.has_sensor_data = True
         self._state = False
